
class SERIALIZATION(object):
	TURTLE = "turtle"
	JSON_LD = "json-ld"
	RDF_XML = "pretty-xml"
	N_TRIPLE = "nt"
	RDF_JSON = "rdf/json"
	RDF_XML_ABBREV = "rdf/xml-abbrev"
	
